@@ -23,6 +23,8 @@ public class BlogConstants
 
     public static final String TEXT_FORMAT_TYPE = "TEXT";
 
+    public static final String HATENA_FORMAT_TYPE = "HATENA";
+
     public static final int DEFAULT_PAGE_SIZE = 10;
 
     public static final int DEFAULT_TITLE_MAX_LENGTH = 20;
@@ -67,4 +69,8 @@ public class BlogConstants
 
     public static final String BLOG_CONTENT_VIEW = "ContentView";
 
+    public static final String COMMENT_ENABLED = "comment-enabled";
+
+    public static final String TRACKBACK_ENABLED = "trackback-enabled";
+
 }
