@@ -15,10 +15,6 @@
  */
 package jp.sf.pal.blog.bean;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-import org.hibernate.HibernateException;
-
 import java.text.DateFormat;
 import java.util.Calendar;
 import java.util.Date;
@@ -27,12 +23,18 @@ import java.util.Locale;
 import javax.faces.component.UIViewRoot;
 import javax.faces.context.ExternalContext;
 import javax.faces.context.FacesContext;
+import javax.faces.model.SelectItem;
 
 import jp.sf.pal.blog.BlogConstants;
 import jp.sf.pal.blog.model.BlogMessage;
 import jp.sf.pal.blog.util.BlogDaoUtil;
 import jp.sf.pal.blog.util.BlogMessaging;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+import org.hibernate.HibernateException;
+
+import com.marevol.utils.faces.application.FacesMessageUtil;
 import com.marevol.utils.portlet.faces.PortletResourceBundleUtil;
 
 public class BlogEditPageBean
@@ -48,12 +50,12 @@ public class BlogEditPageBean
 
     private String message;
 
+    private String formattype;
+
     private Date createdTime;
 
     private Date updatedTime;
 
-    private BlogEditPortletBean editPortlet;
-
     public BlogEditPageBean()
     {
         Long id = null;
@@ -80,6 +82,7 @@ public class BlogEditPageBean
             {
                 setTitle(blogMsg.getTitle());
                 setMessage(blogMsg.getMessage());
+                setFormattype(blogMsg.getFormattype());
                 setCreatedTime(blogMsg.getCreatedtime());
                 setUpdatedTime(blogMsg.getUpdatedtime());
             }
@@ -115,7 +118,7 @@ public class BlogEditPageBean
         if (externalContext.getRemoteUser() == null)
         {
             // i18n
-            getEditPortlet().addMsgError(PortletResourceBundleUtil.getString("blogedit.UnknownUser"));
+            FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil.getString("blogedit.UnknownUser"));
 
             if (log.isDebugEnabled())
             {
@@ -139,20 +142,21 @@ public class BlogEditPageBean
                 Date now = Calendar.getInstance().getTime();
                 blogMsg.setCreatedtime(now);
                 blogMsg.setUpdatedtime(now);
-                blogMsg.setFormattype(BlogConstants.TEXT_FORMAT_TYPE);
+                blogMsg.setFormattype(getFormattype());
                 blogMsg.setTitle(getTitle());
                 blogMsg.setMessage(getMessage());
 
                 BlogDaoUtil.getBlogMessageDao().save(blogMsg);
 
                 // i18n
-                getEditPortlet().setMsgSuccess(PortletResourceBundleUtil.getString("blogedit.SaveMsg"));
+                FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil.getString("blogedit.SaveMsg"));
             }
             catch (RuntimeException e)
             {
                 log.error(e);
                 // i18n
-                getEditPortlet().setMsgError(PortletResourceBundleUtil.getString("blogedit.DatabaseAccessError"));
+                FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil.getString("blogedit.DatabaseAccessError"), e
+                        .toString());
             }
 
         }
@@ -166,20 +170,21 @@ public class BlogEditPageBean
                 Date now = Calendar.getInstance().getTime();
                 // blogMsg.setCreatedtime(now);
                 blogMsg.setUpdatedtime(now);
-                blogMsg.setFormattype(BlogConstants.TEXT_FORMAT_TYPE);
+                blogMsg.setFormattype(getFormattype());
                 blogMsg.setTitle(getTitle());
                 blogMsg.setMessage(getMessage());
 
                 BlogDaoUtil.getBlogMessageDao().saveOrUpdate(blogMsg);
 
                 // i18n
-                getEditPortlet().setMsgSuccess(PortletResourceBundleUtil.getString("blogedit.UpdatedMsg"));
+                FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil.getString("blogedit.UpdatedMsg"));
             }
             catch (HibernateException e)
             {
                 log.error(e);
                 // i18n
-                getEditPortlet().setMsgError(PortletResourceBundleUtil.getString("blogedit.DatabaseAccessError"));
+                FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil.getString("blogedit.DatabaseAccessError"), e
+                        .toString());
             }
 
         }
@@ -197,7 +202,7 @@ public class BlogEditPageBean
         {
             BlogMessaging.cancelForEdit(BlogConstants.BLOG_MESSAGE_ID);
             // i18n
-            getEditPortlet().setMsgInfo(PortletResourceBundleUtil.getString("blogedit.ReadyToCreateANewData"));
+            FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil.getString("blogedit.ReadyToCreateANewData"));
         }
         return null;
     }
@@ -215,20 +220,21 @@ public class BlogEditPageBean
                 setId(null);
 
                 // i18n
-                getEditPortlet().setMsgSuccess(PortletResourceBundleUtil.getString("blogedit.DeletedMsg"));
+                FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil.getString("blogedit.DeletedMsg"));
             }
             catch (HibernateException e)
             {
                 log.error(e);
                 // i18n
-                getEditPortlet().setMsgError(PortletResourceBundleUtil.getString("blogedit.DatabaseAccessError"));
+                FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil.getString("blogedit.DatabaseAccessError"), e
+                        .toString());
             }
 
         }
         else
         {
             // i18n
-            getEditPortlet().setMsgError(PortletResourceBundleUtil.getString("blogedit.TheSpecifiedDataIDIsNull"));
+            FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil.getString("blogedit.TheSpecifiedDataIDIsNull"));
         }
         return null;
     }
@@ -305,41 +311,6 @@ public class BlogEditPageBean
         }
     }
 
-    /**
-     * @return Returns the editPortlet.
-     */
-    public BlogEditPortletBean getEditPortlet()
-    {
-        if (log.isDebugEnabled())
-        {
-            log.debug("getEditPortlet() - start");
-        }
-
-        if (log.isDebugEnabled())
-        {
-            log.debug("getEditPortlet() - end");
-        }
-        return editPortlet;
-    }
-
-    /**
-     * @param editPortlet The editPortlet to set.
-     */
-    public void setEditPortlet(BlogEditPortletBean editPortlet)
-    {
-        if (log.isDebugEnabled())
-        {
-            log.debug("setEditPortlet(BlogEditPortletBean) - start");
-        }
-
-        this.editPortlet = editPortlet;
-
-        if (log.isDebugEnabled())
-        {
-            log.debug("setEditPortlet(BlogEditPortletBean) - end");
-        }
-    }
-
     /**
      * @return Returns the id.
      */
@@ -451,4 +422,32 @@ public class BlogEditPageBean
         this.updatedTime = updatedDate;
     }
 
+    /**
+     * @return Returns the formattype.
+     */
+    public String getFormattype()
+    {
+        if (formattype == null || formattype.equals(""))
+        {
+            return BlogConstants.TEXT_FORMAT_TYPE;
+        }
+        return formattype;
+    }
+
+    /**
+     * @param formattype The formattype to set.
+     */
+    public void setFormattype(String formattype)
+    {
+        this.formattype = formattype;
+    }
+
+    public SelectItem[] getFormattypeItems()
+    {
+        return new SelectItem[] {
+                new SelectItem(BlogConstants.TEXT_FORMAT_TYPE, PortletResourceBundleUtil
+                        .getString("blogedit.TextFormat")),
+                new SelectItem(BlogConstants.HATENA_FORMAT_TYPE, PortletResourceBundleUtil
+                        .getString("blogedit.HatenaFormat")) };
+    }
 }
