@@ -18,6 +18,7 @@ package jp.sf.pal.blog.bean;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.marevol.utils.faces.application.FacesMessageUtil;
 import com.marevol.utils.portlet.faces.PortletPreferencesUtil;
 import com.marevol.utils.portlet.faces.PortletResourceBundleUtil;
 
@@ -44,7 +45,7 @@ public class BlogTitleViewEditPageBean
 
     private Object[] displayedItems;
 
-    private BlogTitleViewPortletBean titleViewPortlet;
+    private BlogTitleViewSessionBean titleViewSession;
 
     public String save()
     {
@@ -55,9 +56,9 @@ public class BlogTitleViewEditPageBean
 
         try
         {
-            getTitleViewPortlet().setOwner(owner);
-            getTitleViewPortlet().setPageSize(pageSize);
-            getTitleViewPortlet().setSortColumn(sortColumn);
+            getTitleViewSession().setOwner(owner);
+            getTitleViewSession().setPageSize(pageSize);
+            getTitleViewSession().setSortColumn(sortColumn);
 
             if (displayedItems != null)
             {
@@ -75,25 +76,25 @@ public class BlogTitleViewEditPageBean
                     }
                 }
 
-                if (!getTitleViewPortlet().getDisplayCreatedtime().equals(createdtime))
+                if (!getTitleViewSession().getDisplayCreatedtime().equals(createdtime))
                 {
-                    getTitleViewPortlet().setDisplayCreatedtime(new Boolean(createdtime));
+                    getTitleViewSession().setDisplayCreatedtime(new Boolean(createdtime));
                 }
-                if (!getTitleViewPortlet().getDisplayUpdatedtime().equals(updatedtime))
+                if (!getTitleViewSession().getDisplayUpdatedtime().equals(updatedtime))
                 {
-                    getTitleViewPortlet().setDisplayUpdatedtime(new Boolean(updatedtime));
+                    getTitleViewSession().setDisplayUpdatedtime(new Boolean(updatedtime));
                 }
 
                 PortletPreferencesUtil.store();
 
                 // i18n
-                titleViewPortlet.addMsgSuccess(PortletResourceBundleUtil.getString("blogtitleview.UpdatedParameters"));
+                FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil.getString("blogtitleview.UpdatedParameters"));
 
             }
             else
             {
                 // i18n
-                titleViewPortlet.addMsgError(PortletResourceBundleUtil
+                FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
                         .getString("blogtitleview.TheSpecifiedItemsAreInvalid"));
                 if (log.isDebugEnabled())
                 {
@@ -105,7 +106,8 @@ public class BlogTitleViewEditPageBean
         catch (IOException e)
         {
             // i18n
-            titleViewPortlet.addMsgError(PortletResourceBundleUtil.getString("blogtitleview.SystemErrorOccurs"));
+            FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil.getString("blogtitleview.SystemErrorOccurs"), e
+                    .toString());
             log.error(e);
         }
 
@@ -125,22 +127,23 @@ public class BlogTitleViewEditPageBean
 
         try
         {
-            getTitleViewPortlet().setOwner(FacesContext.getCurrentInstance().getExternalContext().getRemoteUser());
-            getTitleViewPortlet().setPageSize(new Integer(BlogConstants.DEFAULT_PAGE_SIZE));
-            getTitleViewPortlet().setSortColumn(BlogMessage.CREATEDTIME);
-            getTitleViewPortlet().setDisplayCreatedtime(new Boolean(BlogConstants.FALSE));
-            getTitleViewPortlet().setDisplayUpdatedtime(new Boolean(BlogConstants.FALSE));
+            getTitleViewSession().setOwner(FacesContext.getCurrentInstance().getExternalContext().getRemoteUser());
+            getTitleViewSession().setPageSize(new Integer(BlogConstants.DEFAULT_PAGE_SIZE));
+            getTitleViewSession().setSortColumn(BlogMessage.CREATEDTIME);
+            getTitleViewSession().setDisplayCreatedtime(new Boolean(BlogConstants.FALSE));
+            getTitleViewSession().setDisplayUpdatedtime(new Boolean(BlogConstants.FALSE));
 
             PortletPreferencesUtil.store();
 
             // i18n
-            titleViewPortlet.addMsgSuccess(PortletResourceBundleUtil
+            FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil
                     .getString("blogtitleview.UpdatedToDefaultParameters"));
         }
         catch (IOException e)
         {
             // i18n
-            titleViewPortlet.addMsgError(PortletResourceBundleUtil.getString("blogtitleview.SystemErrorOccurs"));
+            FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil.getString("blogtitleview.SystemErrorOccurs"), e
+                    .toString());
             log.error(e);
         }
 
@@ -168,7 +171,7 @@ public class BlogTitleViewEditPageBean
             log.debug("getPageSize() - end");
         }
         //        return pageSize;
-        return titleViewPortlet.getPageSize();
+        return titleViewSession.getPageSize();
     }
 
     /**
@@ -204,7 +207,7 @@ public class BlogTitleViewEditPageBean
             log.debug("getOwner() - end");
         }
         //return owner;
-        return titleViewPortlet.getOwner();
+        return titleViewSession.getOwner();
     }
 
     /**
@@ -226,9 +229,9 @@ public class BlogTitleViewEditPageBean
     }
 
     /**
-     * @return Returns the titleViewPortlet.
+     * @return Returns the titleViewSession.
      */
-    public BlogTitleViewPortletBean getTitleViewPortlet()
+    public BlogTitleViewSessionBean getTitleViewSession()
     {
         if (log.isDebugEnabled())
         {
@@ -239,24 +242,24 @@ public class BlogTitleViewEditPageBean
         {
             log.debug("getTitleViewPortlet() - end");
         }
-        return titleViewPortlet;
+        return titleViewSession;
     }
 
     /**
-     * @param titleViewPortlet The titleViewPortlet to set.
+     * @param titleViewSession The titleViewSession to set.
      */
-    public void setTitleViewPortlet(BlogTitleViewPortletBean titleViewPortlet)
+    public void setTitleViewSession(BlogTitleViewSessionBean titleViewPortlet)
     {
         if (log.isDebugEnabled())
         {
-            log.debug("setTitleViewPortlet(BlogTitleViewPortletBean) - start");
+            log.debug("setTitleViewPortlet(BlogTitleViewSessionBean) - start");
         }
 
-        this.titleViewPortlet = titleViewPortlet;
+        this.titleViewSession = titleViewPortlet;
 
         if (log.isDebugEnabled())
         {
-            log.debug("setTitleViewPortlet(BlogTitleViewPortletBean) - end");
+            log.debug("setTitleViewPortlet(BlogTitleViewSessionBean) - end");
         }
     }
 
@@ -265,7 +268,7 @@ public class BlogTitleViewEditPageBean
      */
     public String getSortColumn()
     {
-        return getTitleViewPortlet().getSortColumn();
+        return getTitleViewSession().getSortColumn();
     }
 
     /**
@@ -279,11 +282,11 @@ public class BlogTitleViewEditPageBean
     public Object[] getDisplayedItems()
     {
         ArrayList items = new ArrayList();
-        if (getTitleViewPortlet().getDisplayCreatedtime().booleanValue())
+        if (getTitleViewSession().getDisplayCreatedtime().booleanValue())
         {
             items.add(BlogMessage.CREATEDTIME);
         }
-        if (getTitleViewPortlet().getDisplayUpdatedtime().booleanValue())
+        if (getTitleViewSession().getDisplayUpdatedtime().booleanValue())
         {
             items.add(BlogMessage.UPDATEDTIME);
         }
