@@ -19,6 +19,7 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import java.io.NotSerializableException;
+import java.util.ArrayList;
 import java.util.Map;
 
 import javax.faces.context.ExternalContext;
@@ -38,7 +39,7 @@ public class BlogTitleViewPageBean
      */
     private static final Log log = LogFactory.getLog(BlogTitleViewPageBean.class);
 
-    private BlogTitleViewPortletBean titleViewPortlet;
+    private BlogTitleViewSessionBean titleViewSession;
 
     public BlogTitleViewPageBean()
     {
@@ -84,7 +85,7 @@ public class BlogTitleViewPageBean
 
     private String getSortColumn()
     {
-        String column = getTitleViewPortlet().getSortColumn();
+        String column = getTitleViewSession().getSortColumn();
         if (log.isDebugEnabled())
         {
             log.debug("getSortColumn() -  : column=" + column);
@@ -108,9 +109,9 @@ public class BlogTitleViewPageBean
     // Getter and Setter
 
     /**
-     * @return Returns the titleViewPortlet.
+     * @return Returns the titleViewSession.
      */
-    public BlogTitleViewPortletBean getTitleViewPortlet()
+    public BlogTitleViewSessionBean getTitleViewSession()
     {
         if (log.isDebugEnabled())
         {
@@ -121,24 +122,24 @@ public class BlogTitleViewPageBean
         {
             log.debug("getTitleViewPortlet() - end");
         }
-        return titleViewPortlet;
+        return titleViewSession;
     }
 
     /**
-     * @param titleViewPortlet The titleViewPortlet to set.
+     * @param titleViewSession The titleViewSession to set.
      */
-    public void setTitleViewPortlet(BlogTitleViewPortletBean titleViewPortlet)
+    public void setTitleViewSession(BlogTitleViewSessionBean titleViewPortlet)
     {
         if (log.isDebugEnabled())
         {
-            log.debug("setTitleViewPortlet(BlogTitleViewPortletBean) - start");
+            log.debug("setTitleViewPortlet(BlogTitleViewSessionBean) - start");
         }
 
-        this.titleViewPortlet = titleViewPortlet;
+        this.titleViewSession = titleViewPortlet;
 
         if (log.isDebugEnabled())
         {
-            log.debug("setTitleViewPortlet(BlogTitleViewPortletBean) - end");
+            log.debug("setTitleViewPortlet(BlogTitleViewSessionBean) - end");
         }
     }
 
@@ -147,14 +148,32 @@ public class BlogTitleViewPageBean
      */
     public DataModel getBlogMessages()
     {
+        StringBuffer query = new StringBuffer("select msg from BlogMessage msg ");
+        String param = "where ";
+        ArrayList paramList = new ArrayList();
+
+        if (!getTitleViewSession().getOwner().equals(""))
+        {
+            query.append(param);
+            query.append("msg.owner = ? ");
+            param = "and ";
+            paramList.add(getTitleViewSession().getOwner());
+        }
+
+        query.append("order by " + getSortColumn() + " desc");
+
         if (log.isDebugEnabled())
         {
-            log.debug("getBlogMessages()");
+            log.debug("query=" + query.toString());
         }
-        Object[] params = { getTitleViewPortlet().getOwner() };
 
-        return new S2HibernateDataModel("select msg from BlogMessage msg where msg.owner = ? order by " + getSortColumn()
-                + " desc", params);
+        Object[] params = new Object[paramList.size()];
+        for (int i = 0; i < paramList.size(); i++)
+        {
+            params[i] = paramList.get(i);
+        }
+
+        return new S2HibernateDataModel(query.toString(), params);
     }
 
 }
