@@ -24,6 +24,7 @@ import javax.faces.context.FacesContext;
 
 import jp.sf.pal.blog.BlogConstants;
 
+import com.marevol.utils.faces.application.FacesMessageUtil;
 import com.marevol.utils.portlet.faces.PortletPreferencesUtil;
 import com.marevol.utils.portlet.faces.PortletResourceBundleUtil;
 
@@ -38,7 +39,7 @@ public class BlogViewEditPageBean
 
     private Integer pageSize;
 
-    private BlogViewPortletBean viewPortlet;
+    private BlogViewSessionBean viewSession;
 
     public String save()
     {
@@ -49,18 +50,19 @@ public class BlogViewEditPageBean
 
         try
         {
-            getViewPortlet().setOwner(owner);
-            getViewPortlet().setPageSize(pageSize);
+            getViewSession().setOwner(owner);
+            getViewSession().setPageSize(pageSize);
 
             PortletPreferencesUtil.store();
 
             // i18n
-            viewPortlet.addMsgSuccess(PortletResourceBundleUtil.getString("blogview.UpdatedParameters"));
+            FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil.getString("blogview.UpdatedParameters"));
         }
         catch (IOException e)
         {
             // i18n
-            viewPortlet.addMsgError(PortletResourceBundleUtil.getString("blogview.SystemErrorOccurs"));
+            FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil.getString("blogview.SystemErrorOccurs"), e
+                    .toString());
             log.error(e);
         }
 
@@ -80,18 +82,19 @@ public class BlogViewEditPageBean
 
         try
         {
-            getViewPortlet().setOwner(FacesContext.getCurrentInstance().getExternalContext().getRemoteUser());
-            getViewPortlet().setPageSize(new Integer(BlogConstants.DEFAULT_PAGE_SIZE));
+            getViewSession().setOwner(FacesContext.getCurrentInstance().getExternalContext().getRemoteUser());
+            getViewSession().setPageSize(new Integer(BlogConstants.DEFAULT_PAGE_SIZE));
 
             PortletPreferencesUtil.store();
 
             // i18n
-            viewPortlet.addMsgSuccess(PortletResourceBundleUtil.getString("blogview.UpdatedToDefaultParameters"));
+            FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil.getString("blogview.UpdatedToDefaultParameters"));
         }
         catch (IOException e)
         {
             // i18n
-            viewPortlet.addMsgError(PortletResourceBundleUtil.getString("blogview.SystemErrorOccurs"));
+            FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil.getString("blogview.SystemErrorOccurs"), e
+                    .toString());
             log.error(e);
         }
 
@@ -119,7 +122,7 @@ public class BlogViewEditPageBean
             log.debug("getPageSize() - end");
         }
         //        return pageSize;
-        return viewPortlet.getPageSize();
+        return viewSession.getPageSize();
     }
 
     /**
@@ -155,7 +158,7 @@ public class BlogViewEditPageBean
             log.debug("getOwner() - end");
         }
         //return owner;
-        return viewPortlet.getOwner();
+        return viewSession.getOwner();
     }
 
     /**
@@ -177,9 +180,9 @@ public class BlogViewEditPageBean
     }
 
     /**
-     * @return Returns the viewPortlet.
+     * @return Returns the viewSession.
      */
-    public BlogViewPortletBean getViewPortlet()
+    public BlogViewSessionBean getViewSession()
     {
         if (log.isDebugEnabled())
         {
@@ -190,24 +193,24 @@ public class BlogViewEditPageBean
         {
             log.debug("getTitleViewPortlet() - end");
         }
-        return viewPortlet;
+        return viewSession;
     }
 
     /**
-     * @param viewPortlet The viewPortlet to set.
+     * @param viewSession The viewSession to set.
      */
-    public void setViewPortlet(BlogViewPortletBean viewPortlet)
+    public void setViewSession(BlogViewSessionBean viewPortlet)
     {
         if (log.isDebugEnabled())
         {
-            log.debug("setTitleViewPortlet(BlogTitleViewPortletBean) - start");
+            log.debug("setTitleViewPortlet(BlogTitleViewSessionBean) - start");
         }
 
-        this.viewPortlet = viewPortlet;
+        this.viewSession = viewPortlet;
 
         if (log.isDebugEnabled())
         {
-            log.debug("setTitleViewPortlet(BlogTitleViewPortletBean) - end");
+            log.debug("setTitleViewPortlet(BlogTitleViewSessionBean) - end");
         }
     }
 
