@@ -16,20 +16,14 @@
 package jp.sf.pal.blog.bean;
 
 import java.io.NotSerializableException;
+import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Map;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import javax.faces.context.ExternalContext;
 import javax.faces.context.FacesContext;
 import javax.faces.model.DataModel;
 
-import com.marevol.utils.hibernate.faces.model.S2HibernateDataModel;
-import com.marevol.utils.portlet.faces.PortletResourceBundleUtil;
-import com.marevol.utils.portlet.faces.RenderResponseUtil;
-
 import jp.sf.pal.blog.BlogConstants;
 import jp.sf.pal.blog.model.BlogComment;
 import jp.sf.pal.blog.model.BlogMessage;
@@ -37,6 +31,14 @@ import jp.sf.pal.blog.model.BlogTrackback;
 import jp.sf.pal.blog.util.BlogDaoUtil;
 import jp.sf.pal.blog.util.BlogMessaging;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
+import com.marevol.utils.faces.application.FacesMessageUtil;
+import com.marevol.utils.hibernate.faces.model.S2HibernateDataModel;
+import com.marevol.utils.portlet.faces.PortletResourceBundleUtil;
+import com.marevol.utils.portlet.faces.RenderResponseUtil;
+
 public class BlogViewPageBean
 {
     /**
@@ -44,7 +46,7 @@ public class BlogViewPageBean
      */
     private static final Log log = LogFactory.getLog(BlogViewPageBean.class);
 
-    private BlogViewPortletBean viewPortlet;
+    private BlogViewSessionBean viewSession;
 
     private BlogMessage blogMessage;
 
@@ -152,22 +154,23 @@ public class BlogViewPageBean
                     BlogDaoUtil.getBlogCommentDao().save(blogComment);
 
                     // I18n
-                    getViewPortlet().setMsgSuccess(PortletResourceBundleUtil.getString("blogview.PostedTheComment"));
+                    FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil.getString("blogview.PostedTheComment"));
 
                     return null;
                 }
                 else
                 {
                     // I18n
-                    getViewPortlet().setMsgError(PortletResourceBundleUtil.getString("blogview.NameOrCommentsAreNull"));
+                    FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
+                            .getString("blogview.NameOrCommentsAreNull"));
                     log.error(PortletResourceBundleUtil.getString("blogview.NameOrCommentsAreNull"));
                 }
             }
             else
             {
                 // I18n
-                getViewPortlet().setMsgError(
-                        PortletResourceBundleUtil.getString("blogview.CannotFindTheTargetBlogMessage"));
+                FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
+                        .getString("blogview.CannotFindTheTargetBlogMessage"));
                 log.error(PortletResourceBundleUtil.getString("blogview.CannotFindTheTargetBlogMessage"));
             }
         }
@@ -189,14 +192,14 @@ public class BlogViewPageBean
             BlogDaoUtil.getBlogCommentDao().delete(blogCmt);
 
             // I18n
-            getViewPortlet().setMsgSuccess(PortletResourceBundleUtil.getString("blogview.DeletedTheComment"));
+            FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil.getString("blogview.DeletedTheComment"));
 
         }
         else
         {
             // I18n
-            getViewPortlet()
-                    .setMsgError(PortletResourceBundleUtil.getString("blogview.CannotFindTheTargetBlogComment"));
+            FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
+                    .getString("blogview.CannotFindTheTargetBlogComment"));
             log.error(PortletResourceBundleUtil.getString("blogview.CannotFindTheTargetBlogComment"));
         }
         return null;
@@ -212,14 +215,14 @@ public class BlogViewPageBean
             BlogDaoUtil.getBlogTrackbackDao().delete(blogTb);
 
             // I18n
-            getViewPortlet().setMsgSuccess(PortletResourceBundleUtil.getString("blogview.DeletedTheTrackback"));
+            FacesMessageUtil.addInfoMessage(PortletResourceBundleUtil.getString("blogview.DeletedTheTrackback"));
 
         }
         else
         {
             // I18n
-            getViewPortlet()
-                    .setMsgError(PortletResourceBundleUtil.getString("blogview.CannotFindTheTargetBlogTrackback"));
+            FacesMessageUtil.addErrorMessage(PortletResourceBundleUtil
+                    .getString("blogview.CannotFindTheTargetBlogTrackback"));
             log.error(PortletResourceBundleUtil.getString("blogview.CannotFindTheTargetBlogTrackback"));
         }
         return null;
@@ -232,19 +235,38 @@ public class BlogViewPageBean
      */
     public DataModel getBlogMessages()
     {
+        StringBuffer query = new StringBuffer("select msg from BlogMessage msg ");
+        String param = "where ";
+        ArrayList paramList = new ArrayList();
+
+        if (!getViewSession().getOwner().equals(""))
+        {
+            query.append(param);
+            query.append("msg.owner = ? ");
+            param = "and ";
+            paramList.add(getViewSession().getOwner());
+        }
+
+        query.append("order by msg.createdtime desc");
+
         if (log.isDebugEnabled())
         {
-            log.debug("getBlogMessages()");
+            log.debug("query=" + query.toString());
         }
-        Object[] params = { getViewPortlet().getOwner() };
-        return new S2HibernateDataModel(
-                "select msg from BlogMessage msg where msg.owner = ? order by msg.updatedtime desc", params);
+
+        Object[] params = new Object[paramList.size()];
+        for (int i = 0; i < paramList.size(); i++)
+        {
+            params[i] = paramList.get(i);
+        }
+
+        return new S2HibernateDataModel(query.toString(), params);
     }
 
     /**
-     * @return Returns the viewPortlet.
+     * @return Returns the viewSession.
      */
-    public BlogViewPortletBean getViewPortlet()
+    public BlogViewSessionBean getViewSession()
     {
         if (log.isDebugEnabled())
         {
@@ -255,24 +277,24 @@ public class BlogViewPageBean
         {
             log.debug("getViewPortlet() - end");
         }
-        return viewPortlet;
+        return viewSession;
     }
 
     /**
-     * @param viewPortlet The viewPortlet to set.
+     * @param viewSession The viewSession to set.
      */
-    public void setViewPortlet(BlogViewPortletBean viewPortlet)
+    public void setViewSession(BlogViewSessionBean viewPortlet)
     {
         if (log.isDebugEnabled())
         {
-            log.debug("setViewPortlet(BlogViewPortletBean) - start");
+            log.debug("setViewPortlet(BlogViewSessionBean) - start");
         }
 
-        this.viewPortlet = viewPortlet;
+        this.viewSession = viewPortlet;
 
         if (log.isDebugEnabled())
         {
-            log.debug("setViewPortlet(BlogViewPortletBean) - end");
+            log.debug("setViewPortlet(BlogViewSessionBean) - end");
         }
     }
 
